@@ -161,14 +161,13 @@ crmda_html_document <- function(template = "theme/guide-template.html", ...) {
 
 ##' Convert Rmd to PDF
 ##'
-##' It makes sure that the style sheet we want to use is applied to the data.
+##' Convert an Rmd file to PDF by Sweaveing or knitting and then compiling. 
 ##'
 ##' Running this will be the same as running the rmd2pdf.sh script
 ##' within the directory.
-##' @param fn One or more filenames ending in "*.Rmd".
-##' @param wd A working directory name of the Rmd file. If not
-##'     specified, then the current working directory from R will be
-##'     used.
+##' @param fn One or more filenames ending in "*.Rmd". 
+##' @param wd A working directory in which the Rmd file exists. Leave
+##'     as NULL if file is in current working directory,
 ##' @param verbose The opposite of render(quiet = TRUE). Shows compile
 ##'     commentary and pandoc command. Can be informative!
 ##' @param purl Default TRUE
@@ -224,8 +223,8 @@ rmd2pdf <- function(fn = NULL, wd = NULL, ..., verbose = FALSE,
     if (!is.null(wd)){
         wd.orig <- getwd()
         setwd(wd)
-    }
-        
+        on.exit(setwd(wd.orig))
+    }    
     dots <- list(...)
     
     if (length(fn) > 1){
@@ -270,9 +269,6 @@ rmd2pdf <- function(fn = NULL, wd = NULL, ..., verbose = FALSE,
     if(verbose) {print(paste("dots_for_render"));  lapply(dots_for_render, print)}
     res <- do.call(rmarkdown::render, render_argz)
     
-    if (!is.null(wd)){
-        setwd(wd.orig)
-    }
     res
 }
 
@@ -348,8 +344,9 @@ rnw2pdf <- function(fn = NULL, wd = NULL, ..., engine = "knitr", purl = TRUE,
         MESSG <- "rnw2pdf: tangle and purl have the same effect. Just set 1 of them"
         stop(MESSG)
     }
+    
+    wd.orig <- getwd()
     if (!is.null(wd)) {
-        wd.orig <- getwd()
         setwd(wd)
         on.exit(setwd(wd.orig))
     }
@@ -462,7 +459,7 @@ rnw2pdf <- function(fn = NULL, wd = NULL, ..., engine = "knitr", purl = TRUE,
                 }
                 fnbase <- gsub("\\.Rnw$", "", x, ignore.case = TRUE)
                 fntex <- gsub("\\.Rnw$", ".tex", x, ignore.case = TRUE)
-                ## 20180731: Try built-in texi2pdf again, instead of home-made methld
+                ## 20180731: Try built-in texi2pdf again, instead of home-made method
                 tools::texi2pdf(fntex, clean = clean, quiet = quiet)
                 fnpdf <- gsub("\\.Rnw$", ".pdf", x, ignore.case = TRUE)
             }
@@ -474,12 +471,10 @@ rnw2pdf <- function(fn = NULL, wd = NULL, ..., engine = "knitr", purl = TRUE,
             return("Failed")
         }
     }
-
-    res <- list()
-    for(i in fn){
-        res[[i]] <- compileme(i)
+    res <- character(length = length(fn))
+    for (i in seq_along(fn)) {
+        newfn <- compileme(fn[i])
+        res[i] <- file.path(wd.orig, newfn)
     }
-    res <- file.path(wd, res)
     res
 }
-
